@@ -16,7 +16,8 @@ from sklearn.base import BaseEstimator
 from sklearn.base import MetaEstimatorMixin
 from sklearn.base import clone
 from sklearn.feature_selection import SelectorMixin
-from sklearn.model_selection import cross_val_score
+from sklearn.model_selection import cross_val_score, GridSearchCV
+from sklearn.model_selection._search import BaseSearchCV
 from sklearn.utils.metaestimators import if_delegate_has_method
 from sklearn.utils.validation import check_is_fitted, check_X_y
 
@@ -34,9 +35,11 @@ class Exhaustion(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
 
     Examples
     ----------
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
-    >>> X,y = load_boston(return_X_y=True)
+    >>> X,y = fetch_california_housing(return_X_y=True)
+    >>> X = X[:100]
+    >>> y = y[:100]
     >>> svr= SVR()
     >>> bf = Exhaustion(svr,n_select=(2,),refit=True)
     >>> new_x = bf.fit_transform(X,y)
@@ -46,9 +49,11 @@ class Exhaustion(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
 
     Examples
     ----------
-    >>> from sklearn.datasets import load_boston
+    >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
-    >>> X,y = load_boston(return_X_y=True)
+    >>> X,y = fetch_california_housing(return_X_y=True)
+    >>> X = X[:100]
+    >>> y = y[:100]
     >>> svr= SVR()
     >>> from sklearn import model_selection
     >>> gd = model_selection.GridSearchCV(svr, param_grid=[{"C": [1, 10]}], n_jobs=1, cv=5)
@@ -135,7 +140,7 @@ class Exhaustion(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
                 else:
                     estimator_ = estimator
 
-                if hasattr(estimator_, "best_score_"):
+                if hasattr(estimator_, "best_score_") or isinstance(estimator_, BaseSearchCV):
                     estimator_.fit(data_x0, y0)
                     score0 = np.mean(estimator_.best_score_)  # score_test
                 elif self.cv == 0:
